# data-pipelines-cli

CLI for data platform

## Installation
TODO

## Usage
First, run `dp init` to configure your first template. `dp init` will allow you to add more templates later. Then, you can use `dp create <new-project-path>` to choose one of the templates added before and create the project in `<new-project-path>` directory.

`dp list` lists all added templates.

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.